-- MySQL dump 10.16  Distrib 10.1.23-MariaDB, for debian-linux-gnu (x86_64)
--
-- Host: localhost    Database: mylvs
-- ------------------------------------------------------
-- Server version	10.1.23-MariaDB-9+deb9u1

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8mb4 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;


--
-- Current Database: `mylvs`
--

CREATE DATABASE /*!32312 IF NOT EXISTS*/ `mylvs` /*!40100 DEFAULT CHARACTER SET latin1 */;

USE `mylvs`;

--
-- Grant access to the demo user mylvsuser
--


GRANT ALL PRIVILEGES ON mylvs.* TO mylvsuser@localhost IDENTIFIED BY 'demo';

--
-- Table structure for table `tblCommands`
-- 

--
-- Table structure for table `tblCommands`
--

DROP TABLE IF EXISTS `tblCommands`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblCommands` (
  `cmdID` double NOT NULL DEFAULT '0',
  `enabled` int(1) DEFAULT NULL,
  `name` varchar(64) DEFAULT NULL,
  `command` varchar(255) DEFAULT NULL,
  `type` int(11) DEFAULT NULL,
  `type-description` varchar(16) DEFAULT NULL,
  PRIMARY KEY (`cmdID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblCommands`
--

LOCK TABLES `tblCommands` WRITE;
/*!40000 ALTER TABLE `tblCommands` DISABLE KEYS */;
INSERT INTO `tblCommands` VALUES (1,1,'Reset IIS','/usr/lib/nagios/plugins/check_nrpe -H %HOST% -p 5666 -c reset_iis',2,'Reset Service'),(2,1,'Restart Apache','/usr/lib/nagios/plugins/check_nrpe -H %HOST% -p 5666 -c reset_apache',2,'Reset Service'),(3,1,'Reboot Server','/usr/lib/nagios/plugins/check_nrpe -H %HOST% -p 5666 -c reboot',2,'Reboot Server'),(4,1,'Check HTTP','/usr/lib/nagios/plugins/check_http -H %HOST%',1,'Check IIS');
/*!40000 ALTER TABLE `tblCommands` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblCustomFlags`
--

DROP TABLE IF EXISTS `tblCustomFlags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblCustomFlags` (
  `cID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `ipFrom` varchar(15) NOT NULL DEFAULT '',
  `ipTo` varchar(15) NOT NULL DEFAULT '',
  `imgDescription` varchar(45) NOT NULL DEFAULT '',
  `imgFlagPath` varchar(45) NOT NULL DEFAULT '',
  PRIMARY KEY (`cID`)
) ENGINE=MyISAM AUTO_INCREMENT=15 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblCustomFlags`
--

LOCK TABLES `tblCustomFlags` WRITE;
/*!40000 ALTER TABLE `tblCustomFlags` DISABLE KEYS */;
/*!40000 ALTER TABLE `tblCustomFlags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblDailyBlackout`
--

DROP TABLE IF EXISTS `tblDailyBlackout`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblDailyBlackout` (
  `bID` double NOT NULL DEFAULT '0',
  `groupID` int(11) DEFAULT NULL,
  `enabled` int(1) DEFAULT NULL,
  `Name` varchar(24) DEFAULT NULL,
  `BlackoutFrom` varchar(5) DEFAULT NULL,
  `Blackoutto` varchar(5) DEFAULT NULL,
  PRIMARY KEY (`bID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblDailyBlackout`
--

LOCK TABLES `tblDailyBlackout` WRITE;
/*!40000 ALTER TABLE `tblDailyBlackout` DISABLE KEYS */;
/*!40000 ALTER TABLE `tblDailyBlackout` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblIP2Country`
--

DROP TABLE IF EXISTS `tblIP2Country`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblIP2Country` (
  `ID` double NOT NULL DEFAULT '0',
  `ipfrom` bigint(8) DEFAULT NULL,
  `ipto` bigint(8) DEFAULT NULL,
  `registry` varchar(16) DEFAULT NULL,
  `assigned` varchar(16) DEFAULT NULL,
  `ctry` char(3) DEFAULT NULL,
  `cntry` char(3) DEFAULT NULL,
  `country` varchar(24) DEFAULT NULL,
  PRIMARY KEY (`ID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblIP2Country`
--

LOCK TABLES `tblIP2Country` WRITE;
/*!40000 ALTER TABLE `tblIP2Country` DISABLE KEYS */;
/*!40000 ALTER TABLE `tblIP2Country` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblLogCode`
--

DROP TABLE IF EXISTS `tblLogCode`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblLogCode` (
  `code` double NOT NULL DEFAULT '0',
  `image` varchar(64) DEFAULT NULL,
  PRIMARY KEY (`code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblLogCode`
--

LOCK TABLES `tblLogCode` WRITE;
/*!40000 ALTER TABLE `tblLogCode` DISABLE KEYS */;
INSERT INTO `tblLogCode` VALUES (1,'/images/critical.png'),(2,'/images/warning.png'),(3,'/images/info.png'),(4,'/images/unknown.png'),(5,'/images/hostevent.gif'),(6,'/images/recovery.png'),(7,'/images/notify.gif'),(8,'/images/stop.gif'),(9,'/images/start.gif'),(10,'/images/command.png'),(11,'/images/ack.gif'),(12,'/images/logrotate.png');
/*!40000 ALTER TABLE `tblLogCode` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblLogging`
--

DROP TABLE IF EXISTS `tblLogging`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblLogging` (
  `logID` double NOT NULL AUTO_INCREMENT,
  `user` varchar(16) DEFAULT NULL,
  `code` int(16) DEFAULT NULL,
  `day` int(2) DEFAULT NULL,
  `month` int(2) DEFAULT NULL,
  `year` int(4) DEFAULT NULL,
  `hour` int(2) DEFAULT NULL,
  `minute` int(2) DEFAULT NULL,
  `second` int(2) DEFAULT NULL,
  `message` varchar(255) DEFAULT NULL,
  `epoche` int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`logID`)
) ENGINE=MyISAM AUTO_INCREMENT=343 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblLogging`
--

LOCK TABLES `tblLogging` WRITE;
/*!40000 ALTER TABLE `tblLogging` DISABLE KEYS */;
INSERT INTO `tblLogging` VALUES (338,'demo',2,25,7,2017,14,47,47,'Delete Backup: /var/www/mylvs/backup//20150822-151653.sql',1501008467),(339,'demo',2,25,7,2017,14,47,51,'Delete Backup: /var/www/mylvs/backup//20150822-161718.sql',1501008471),(340,'demo',2,25,7,2017,14,48,6,'Apply Comment: First setup',1501008486),(341,'demo',2,25,7,2017,14,48,6,'Apply Backup Comment:  /usr/bin/sudo /var/www/mylvs/scripts/mkbackup.sh mylvs mylvsuser pass /var/www/mylvs/backup/ 20170725-144759.sql',1501008486),(342,'demo',2,25,7,2017,14,48,16,'Delete Backup: /var/www/mylvs/backup//20150827-135828.sql',1501008496);
/*!40000 ALTER TABLE `tblLogging` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblMaintenance`
--

DROP TABLE IF EXISTS `tblMaintenance`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblMaintenance` (
  `mID` double NOT NULL DEFAULT '0',
  `enabled` int(1) DEFAULT NULL,
  `ip` varchar(16) DEFAULT NULL,
  `hostname` varchar(16) DEFAULT NULL,
  `groupID` int(1) DEFAULT NULL,
  `requestUP` int(1) DEFAULT NULL,
  `requestDOWN` int(1) DEFAULT NULL,
  `WeightDownTime` int(8) DEFAULT NULL,
  `WeightDownPending` int(1) DEFAULT NULL,
  `TurnOffTime` int(8) DEFAULT NULL,
  `TurnOffPending` int(1) DEFAULT NULL,
  `response` int(1) DEFAULT NULL,
  `message` varchar(128) DEFAULT NULL,
  `updatepending` int(1) DEFAULT NULL,
  `requestDate` varchar(24) DEFAULT NULL,
  `responseDate` varchar(24) DEFAULT NULL,
  `receivedfrom` varchar(64) DEFAULT NULL,
  `CurWeightDownTime` varchar(64) DEFAULT NULL,
  `CurTurnOffTime` varchar(64) DEFAULT NULL,
  `DSLMaintenance` int(1) unsigned NOT NULL,
  `DSLRenewRequest` int(1) unsigned NOT NULL,
  `DSLDate` varchar(24) NOT NULL,
  `DSLEpoche` int(10) unsigned NOT NULL,
  `DSLIP` varchar(64) NOT NULL,
  PRIMARY KEY (`mID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblMaintenance`
--

LOCK TABLES `tblMaintenance` WRITE;
/*!40000 ALTER TABLE `tblMaintenance` DISABLE KEYS */;
INSERT INTO `tblMaintenance` VALUES (1,1,'192.168.2.221','hh',1,0,0,30,0,30,0,200,'Host has been turned on',0,'0','20150727143609','0','0','0',0,0,'0',0,'0'),(2,1,'192.168.2.222','hh',1,0,0,35,0,35,0,200,'Host has been turned on',0,'0','20150727152859','0','0','0',0,0,'0',0,'0');
/*!40000 ALTER TABLE `tblMaintenance` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblMaintenanceGroup`
--

DROP TABLE IF EXISTS `tblMaintenanceGroup`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblMaintenanceGroup` (
  `gID` double DEFAULT NULL,
  `GroupRemoveMax` int(1) DEFAULT NULL,
  `GroupMinAvailable` int(1) DEFAULT NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblMaintenanceGroup`
--

LOCK TABLES `tblMaintenanceGroup` WRITE;
/*!40000 ALTER TABLE `tblMaintenanceGroup` DISABLE KEYS */;
/*!40000 ALTER TABLE `tblMaintenanceGroup` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblMessaging`
--

DROP TABLE IF EXISTS `tblMessaging`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblMessaging` (
  `mid` double NOT NULL DEFAULT '0',
  `type` int(8) DEFAULT NULL,
  `mailfrom` varchar(32) DEFAULT NULL,
  `server` varchar(32) DEFAULT NULL,
  `mailto` varchar(128) DEFAULT NULL,
  `mailcc` varchar(128) DEFAULT NULL,
  `mailbcc` varchar(128) DEFAULT NULL,
  `title` varchar(32) DEFAULT NULL,
  PRIMARY KEY (`mid`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblMessaging`
--

LOCK TABLES `tblMessaging` WRITE;
/*!40000 ALTER TABLE `tblMessaging` DISABLE KEYS */;
INSERT INTO `tblMessaging` VALUES (1,1,'mylvs@domain.com','mail.domain.com','admin@domain.com',NULL,NULL,'IT-Group');
/*!40000 ALTER TABLE `tblMessaging` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblMonitor`
--

DROP TABLE IF EXISTS `tblMonitor`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblMonitor` (
  `monID` double NOT NULL DEFAULT '0',
  `enabled` int(1) DEFAULT NULL,
  `invID` double DEFAULT NULL,
  `recTaskID` double DEFAULT NULL,
  `timeout` int(8) DEFAULT NULL,
  `checkalive` int(8) DEFAULT NULL,
  `checkinterval` int(8) DEFAULT NULL,
  `failcheckinterval` int(8) DEFAULT NULL,
  `rechecks` int(8) DEFAULT NULL,
  `recheckwait` int(8) DEFAULT NULL,
  `notificationclock` int(8) DEFAULT NULL,
  `messageid` int(8) DEFAULT NULL,
  `checkinventory` int(8) DEFAULT NULL,
  `immediaterecoverid` int(8) DEFAULT NULL,
  `commandid` int(8) DEFAULT NULL,
  `lastcheck` varchar(16) DEFAULT NULL,
  `status` varchar(8) DEFAULT NULL,
  PRIMARY KEY (`monID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblMonitor`
--

LOCK TABLES `tblMonitor` WRITE;
/*!40000 ALTER TABLE `tblMonitor` DISABLE KEYS */;
INSERT INTO `tblMonitor` VALUES (1,1,1,1,5,1,10,5,5,5,1800,1,1,1,4,'1440106095','UNKNOWN'),(2,1,2,2,5,1,10,5,5,5,1800,1,1,2,4,'1440110361','UNKNOWN');
/*!40000 ALTER TABLE `tblMonitor` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblNodes`
--

DROP TABLE IF EXISTS `tblNodes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblNodes` (
  `nodeID` double NOT NULL DEFAULT '0',
  `enabled` int(1) DEFAULT NULL,
  `Name` varchar(24) DEFAULT NULL,
  `scheduler` varchar(8) DEFAULT NULL,
  `service` char(3) DEFAULT NULL,
  `vip` varchar(20) DEFAULT NULL,
  `vip6` varchar(51) DEFAULT NULL,
  `persistent` int(8) DEFAULT NULL,
  `monitor` int(1) DEFAULT NULL,
  PRIMARY KEY (`nodeID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblNodes`
--

LOCK TABLES `tblNodes` WRITE;
/*!40000 ALTER TABLE `tblNodes` DISABLE KEYS */;
INSERT INTO `tblNodes` VALUES (1,1,'Demo-Node01','wlc','tcp','192.168.2.220:80','',0,1);
/*!40000 ALTER TABLE `tblNodes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblNodesInventory`
--

DROP TABLE IF EXISTS `tblNodesInventory`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblNodesInventory` (
  `invID` double NOT NULL DEFAULT '0',
  `resID` double DEFAULT NULL,
  `nodeID` double DEFAULT NULL,
  `snmpID` double DEFAULT NULL,
  `enabled` int(1) DEFAULT NULL,
  `active` int(1) DEFAULT NULL,
  `maintenance` int(1) DEFAULT NULL,
  `failstate` int(1) DEFAULT NULL,
  `port` int(8) DEFAULT NULL,
  `method` char(1) DEFAULT NULL,
  `link` varchar(128) DEFAULT NULL,
  `weight` int(8) DEFAULT NULL,
  `automovepoolid` int(1) DEFAULT NULL,
  `weightdown` int(1) DEFAULT NULL,
  `cmd_reset_id` int(8) DEFAULT NULL,
  `bid` int(8) DEFAULT NULL,
  PRIMARY KEY (`invID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblNodesInventory`
--

LOCK TABLES `tblNodesInventory` WRITE;
/*!40000 ALTER TABLE `tblNodesInventory` DISABLE KEYS */;
INSERT INTO `tblNodesInventory` VALUES (1,1,1,0,1,1,0,1,80,'g','WEB-01:IIS',100,0,0,1,1),(2,2,1,0,1,1,0,1,80,'g','Web-02:Apache',100,0,0,2,1);
/*!40000 ALTER TABLE `tblNodesInventory` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblPermission`
--

DROP TABLE IF EXISTS `tblPermission`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblPermission` (
  `perID` double NOT NULL DEFAULT '0',
  `name` varchar(128) DEFAULT NULL,
  `usrID` double DEFAULT NULL,
  PRIMARY KEY (`perID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblPermission`
--

LOCK TABLES `tblPermission` WRITE;
/*!40000 ALTER TABLE `tblPermission` DISABLE KEYS */;
/*!40000 ALTER TABLE `tblPermission` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblPoolResources`
--

DROP TABLE IF EXISTS `tblPoolResources`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblPoolResources` (
  `poolindex` double NOT NULL DEFAULT '0',
  `poolid` int(8) DEFAULT NULL,
  `resID` double DEFAULT NULL,
  `name` varchar(32) DEFAULT NULL,
  PRIMARY KEY (`poolindex`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblPoolResources`
--

LOCK TABLES `tblPoolResources` WRITE;
/*!40000 ALTER TABLE `tblPoolResources` DISABLE KEYS */;
/*!40000 ALTER TABLE `tblPoolResources` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblRecover`
--

DROP TABLE IF EXISTS `tblRecover`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblRecover` (
  `recID` double NOT NULL DEFAULT '0',
  `enabled` int(1) DEFAULT NULL,
  `name` varchar(64) DEFAULT NULL,
  `command` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`recID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblRecover`
--

LOCK TABLES `tblRecover` WRITE;
/*!40000 ALTER TABLE `tblRecover` DISABLE KEYS */;
INSERT INTO `tblRecover` VALUES (1,1,'Reset IIS','/usr/lib/nagios/plugins/check_nrpe -H %HOST% -p 5666 -c reset_iis'),(2,1,'Reset Apache','/usr/lib/nagios/plugins/check_nrpe -H %HOST% -p 5666 -c reset_apache'),(3,1,'Reboot','/usr/lib/nagios/plugins/check_nrpe -H %HOST% -p 5666 -c reboot');
/*!40000 ALTER TABLE `tblRecover` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblRecoverTasks`
--

DROP TABLE IF EXISTS `tblRecoverTasks`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblRecoverTasks` (
  `TaskID` double NOT NULL DEFAULT '0',
  `recTaskID` double DEFAULT NULL,
  `recID` double DEFAULT NULL,
  `recClock` int(8) DEFAULT NULL,
  `title` varchar(32) DEFAULT NULL,
  PRIMARY KEY (`TaskID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblRecoverTasks`
--

LOCK TABLES `tblRecoverTasks` WRITE;
/*!40000 ALTER TABLE `tblRecoverTasks` DISABLE KEYS */;
INSERT INTO `tblRecoverTasks` VALUES (1,1,1,2,'Reset IIS'),(2,1,3,5,'Reset IIS'),(3,2,2,1,'Reset Apache'),(4,2,3,2,'Reset Apache');
/*!40000 ALTER TABLE `tblRecoverTasks` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblResources`
--

DROP TABLE IF EXISTS `tblResources`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblResources` (
  `resID` double NOT NULL DEFAULT '0',
  `enabled` int(1) DEFAULT NULL,
  `alias` varchar(128) DEFAULT NULL,
  `realip` varchar(15) DEFAULT NULL,
  `realip6` varchar(45) DEFAULT NULL,
  `cmd_reboot_id` int(8) DEFAULT NULL,
  `mrtg_link` varchar(128) DEFAULT NULL,
  `visible` int(1) unsigned DEFAULT NULL,
  `mac` varchar(17) DEFAULT NULL,
  `cmd_shutdown_id` int(8) unsigned DEFAULT NULL,
  `cmd_wakeup_id` int(8) unsigned DEFAULT NULL,
  PRIMARY KEY (`resID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblResources`
--

LOCK TABLES `tblResources` WRITE;
/*!40000 ALTER TABLE `tblResources` DISABLE KEYS */;
INSERT INTO `tblResources` VALUES (1,1,'WEB-01','192.168.2.221','',3,'-',1,'-',0,0),(2,1,'WEB-02','192.168.2.222',NULL,3,'-',1,'-',0,0);
/*!40000 ALTER TABLE `tblResources` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblSNMP`
--

DROP TABLE IF EXISTS `tblSNMP`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblSNMP` (
  `snmpID` double NOT NULL DEFAULT '0',
  `Name` varchar(32) DEFAULT NULL,
  `snmpkey` varchar(128) DEFAULT NULL,
  `snmppass` varchar(16) DEFAULT NULL,
  `snmpport` int(8) DEFAULT NULL,
  `snmptimeout` int(8) DEFAULT NULL,
  PRIMARY KEY (`snmpID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblSNMP`
--

LOCK TABLES `tblSNMP` WRITE;
/*!40000 ALTER TABLE `tblSNMP` DISABLE KEYS */;
/*!40000 ALTER TABLE `tblSNMP` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblState`
--

DROP TABLE IF EXISTS `tblState`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblState` (
  `stateID` double NOT NULL DEFAULT '0',
  `statechange` int(8) DEFAULT NULL,
  PRIMARY KEY (`stateID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblState`
--

LOCK TABLES `tblState` WRITE;
/*!40000 ALTER TABLE `tblState` DISABLE KEYS */;
/*!40000 ALTER TABLE `tblState` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tblUsers`
--

DROP TABLE IF EXISTS `tblUsers`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tblUsers` (
  `userID` double NOT NULL DEFAULT '0',
  `name` varchar(32) DEFAULT NULL,
  `operations` int(1) DEFAULT NULL,
  `logview` int(1) DEFAULT NULL,
  `showcon` int(1) DEFAULT NULL,
  `searchcon` int(1) DEFAULT NULL,
  `reset` int(1) DEFAULT NULL,
  `reboot` int(1) DEFAULT NULL,
  `search` int(1) DEFAULT NULL,
  `whois` int(1) DEFAULT NULL,
  `nslookup` int(1) DEFAULT NULL,
  `scan` int(1) DEFAULT NULL,
  `servermanager` int(1) unsigned DEFAULT NULL,
  PRIMARY KEY (`userID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tblUsers`
--

LOCK TABLES `tblUsers` WRITE;
/*!40000 ALTER TABLE `tblUsers` DISABLE KEYS */;
INSERT INTO `tblUsers` VALUES (1,'demo',1,1,1,1,1,1,1,1,1,1,1);
/*!40000 ALTER TABLE `tblUsers` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2017-07-25 15:23:55
